#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_bbs9sryhpq/croot/libxslt_1692973469556/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib"
XSLT_LIBS="-lxslt -L/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_bbs9sryhpq/croot/libxslt_1692973469556/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/lib -lxml2 "
XSLT_PRIVATE_LIBS=""
XSLT_INCLUDEDIR="-I/var/folders/c_/qfmhj66j0tn016nkx_th4hxm0000gp/T/abs_bbs9sryhpq/croot/libxslt_1692973469556/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placeh/include"
MODULE_VERSION="xslt-1.1.37"
